@@ -7,7 +7,7 @@ system_check <- function(cmd) {
 }
 
 R <- function(options) {
-  r_path <- file.path(R.home("bin"), "R")
+  r_path <- shQuote(file.path(R.home("bin"), "R"))
   system_check(paste(r_path, options))
   
 }
\ No newline at end of file
